"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PdfHandler = exports.browserRendering = void 0;

var React = _interopRequireWildcard(require("react"));

var _reactWindow = require("react-window");

var _SelectionHandler = require("./SelectionHandler");

var _SelectionRegion = require("./SelectionRegion");

var _Highlight = require("./Highlight");

var _reactPdf = require("react-pdf");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const browserRendering = typeof document !== 'undefined';
exports.browserRendering = browserRendering;
_reactPdf.pdfjs.GlobalWorkerOptions.workerSrc = `//cdnjs.cloudflare.com/ajax/libs/pdf.js/${_reactPdf.pdfjs.version}/pdf.worker.js`;

const PdfHandler = ({
  url,
  highlights,
  goToHighlight,
  onTextSelection
}) => {
  const [documentPageNumber, setDocumentPageNumber] = (0, React.useState)(0);
  const gridRef = /*#__PURE__*/React.createRef();

  const showHighlights = pageNumber => {
    if (!highlights || !highlights[0]) {
      return;
    }

    return highlights.map(highlight => {
      const pageRectangles = highlight.selectionRectangles.filter(rectangle => rectangle.pageNumber == pageNumber);

      if (pageRectangles.length === 0) {
        return;
      }

      return /*#__PURE__*/React.createElement(_Highlight.Highlight, {
        highlight: {
          selectionRectangles: pageRectangles
        }
      });
    });
  };

  function removeTextLayerOffset() {
    const textLayers = document.querySelectorAll('.react-pdf__Page__textContent');
    textLayers.forEach(layer => {
      // @ts-ignore
      const {
        style
      } = layer;
      style.top = '0';
      style.left = '0';
      style.transform = '';
    });
  }

  const PageHandler = ({
    index,
    style
  }) => {
    if (browserRendering) {
      const {
        Page
      } = require('react-pdf');

      return /*#__PURE__*/React.createElement("div", {
        style: style
      }, /*#__PURE__*/React.createElement(_SelectionRegion.SelectionRegion, {
        regionId: (index + 1).toString()
      }, /*#__PURE__*/React.createElement(Page, {
        height: 850,
        onLoadError: error => console.error(error),
        pageNumber: index + 1,
        onLoadSuccess: removeTextLayerOffset,
        renderMode: 'svg'
      }, showHighlights(index + 1))));
    }
  };

  (0, React.useEffect)(() => {
    if (!goToHighlight || !gridRef.current || !goToHighlight.selectionRectangles || !goToHighlight.selectionRectangles[0].pageNumber) {
      return;
    }

    gridRef.current.scrollToItem(goToHighlight.selectionRectangles[0].pageNumber - 1);
  });

  function onDocumentLoadSuccess({
    numPages
  }) {
    setDocumentPageNumber(numPages);
  }

  if (browserRendering) {
    const {
      Document
    } = require('react-pdf');

    return browserRendering && /*#__PURE__*/React.createElement(_SelectionHandler.SelectionHandler, {
      onTextSelection: onTextSelection
    }, /*#__PURE__*/React.createElement(Document, {
      file: url,
      onLoadSuccess: onDocumentLoadSuccess
    }, /*#__PURE__*/React.createElement(_reactWindow.FixedSizeList, {
      height: 850,
      itemCount: documentPageNumber,
      itemSize: 850,
      width: 640,
      ref: gridRef
    }, PageHandler)));
  }
};

exports.PdfHandler = PdfHandler;